==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/post_processor.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php defined("HELLO") or exit(); ?>
<?php
$post_return = $_POST['return'];
$post_posting = $_POST['posting'];
if ($post_posting == 'favo'){
  $post_entry = $_POST['entry'];
  $api = "{$api_base_url}favorites/create/{$post_entry}.xml";
  unset($_POST['entry']);
} elseif ($post_posting == 'hateb'){
  $post_url = $_POST['url'];
  $post_comment = $_POST['comment'];
  $api = "http://b.hatena.ne.jp/atom/post";
  unset($_POST['url'], $_POST['comment']);
} else {
  if ($_POST['status'] == ''){
	$redirect = 'http://'.$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF']).'/entries.php?keyword='.rawurlencode($_POST['keyword']);
	header('HTTP/1.1 303 See Other');
	header('Location: '.$redirect);
	exit();
  }
	$api = "{$api_base_url}statuses/update.xml";
}
unset($_POST['return'], $_POST['posting']);
$postd = $_POST;
/*var_dump($_SESSION);
var_dump($_POST);
exit();*/
if ($post_posting == 'favo' || $post_posting == 'status'){
$_SESSION['post_to'] = 'haiku';
  $json = postGeneric($api, $postd, $conkey, $conkey_sec, $_SESSION['acstoken'], $_SESSION['acs_sec']);
  if ($json['stat'] === TRUE){
	$json_body = $json['body'];
	  $_SESSION['post_result'] = TRUE;
	  if ($post_posting == 'status'){
		$_SESSION['post_result_mes'] = '投稿しました。';
	  } elseif ($post_posting == 'favo'){
		$_SESSION['post_result_mes'] = '.｡.:*･゜ﾟ･*☆';
	  } else {
		$_SESSION['post_result_mes'] = '投稿しました。';
	  }
	  $_SESSION['post_body'] = $json_body;
  } else {
	  $_SESSION['post_result'] = FALSE;
	  $_SESSION['post_result_mes'] = 'なんかのエラーですすす。';
	  $_SESSION['post_error'] = $json['error'];
// 	  $_SESSION['post_session'] = $json['session'];
  }
} elseif ($post_posting == 'hateb'){
  $_SESSION['post_to'] = 'hateb';
  $body = <<<EOL
<entry xmlns="http://purl.org/atom/ns#">
  <title>dummy</title>
  <link rel="related" type="text/html" href="{$post_url}" />
  <summary type="text/plain">{$post_comment}</summary>
</entry>
EOL;
  $xml = postGeneric($api, $postd, $conkey, $conkey_sec, $_SESSION['acstoken'], $_SESSION['acs_sec'], $body);
  if ($xml['http'] != '201'){
	$_SESSION['post_result'] = FALSE;
	$_SESSION['post_result_mes'] = 'なんかのエラーです。';
	$_SESSION['post_error'] = $xml['body'];
  } else {
	$_SESSION['post_result'] = TRUE;
	$_SESSION['post_result_mes'] = 'ブックマークを投稿しました。';
	$_SESSION['post_body'] = $xml['body'];
  }
}
// 	if (preg_match("/.*Android.*Mobile Safari.*/u", $_SERVER['HTTP_USER_AGENT']) || preg_match("/.*PalmOS.*NetFront.*/u", $_SERVER['HTTP_USER_AGENT'])){
// 	} else {
header('HTTP/1.1 303 See Other');
header('Location: ' . $post_return);
exit();
// 	}
?>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/post_processor.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php defined("HELLO") or exit(); ?>
<?php
$post_return = $_POST['return'];
$post_posting = $_POST['posting'];
if ($post_posting == 'favo'){
  $post_entry = $_POST['entry'];
  $api = "{$api_base_url}favorites/create/{$post_entry}.xml?body_formats=html_touch,api";
  unset($_POST['entry']);
} elseif ($post_posting == 'hateb'){
  $post_url = $_POST['url'];
  $post_comment = $_POST['comment'];
  $api = "http://b.hatena.ne.jp/atom/post";
  unset($_POST['url'], $_POST['comment']);
} else {
  if ($_POST['status'] == ''){
	$redirect = 'http://'.$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF']).'/entries.php?keyword='.rawurlencode($_POST['keyword']);
	header('HTTP/1.1 303 See Other');
	header('Location: '.$redirect);
	exit();
  }
	$api = "{$api_base_url}statuses/update.xml?body_formats=html_touch,api";
}
unset($_POST['return'], $_POST['posting']);
$postd = $_POST;
/*var_dump($_SESSION);
var_dump($_POST);
exit();*/
if ($post_posting == 'favo' || $post_posting == 'status'){
$_SESSION['post_to'] = 'haiku';
  $json = postGeneric($api, $postd, $conkey, $conkey_sec, $_SESSION['acstoken'], $_SESSION['acs_sec']);
  if ($json['stat'] === TRUE){
	$json_body = $json['body'];
	  $_SESSION['post_result'] = TRUE;
	  if ($post_posting == 'status'){
		$_SESSION['post_result_mes'] = '投稿しました。';
	  } elseif ($post_posting == 'favo'){
		$_SESSION['post_result_mes'] = '.｡.:*･゜ﾟ･*☆';
	  } else {
		$_SESSION['post_result_mes'] = '投稿しました。';
	  }
	  $_SESSION['post_body'] = $json_body;
  } else {
	  $_SESSION['post_result'] = FALSE;
	  $_SESSION['post_result_mes'] = 'なんかのエラーですすす。';
	  $_SESSION['post_error'] = $json['error'];
// 	  $_SESSION['post_session'] = $json['session'];
  }
} elseif ($post_posting == 'hateb'){
  $_SESSION['post_to'] = 'hateb';
  $body = <<<EOL
<entry xmlns="http://purl.org/atom/ns#">
  <title>dummy</title>
  <link rel="related" type="text/html" href="{$post_url}" />
  <summary type="text/plain">{$post_comment}</summary>
</entry>
EOL;
  $xml = postGeneric($api, $postd, $conkey, $conkey_sec, $_SESSION['acstoken'], $_SESSION['acs_sec'], $body);
  if ($xml['http'] != '201'){
	$_SESSION['post_result'] = FALSE;
	$_SESSION['post_result_mes'] = 'なんかのエラーです。';
	$_SESSION['post_error'] = $xml['body'];
  } else {
	$_SESSION['post_result'] = TRUE;
	$_SESSION['post_result_mes'] = 'ブックマークを投稿しました。';
	$_SESSION['post_body'] = $xml['body'];
  }
}
// 	if (preg_match("/.*Android.*Mobile Safari.*/u", $_SERVER['HTTP_USER_AGENT']) || preg_match("/.*PalmOS.*NetFront.*/u", $_SERVER['HTTP_USER_AGENT'])){
// 	} else {
header('HTTP/1.1 303 See Other');
header('Location: ' . $post_return);
exit();
// 	}
?>
